package example.account;

import java.util.List;

/**
 * Interface representing a Bank Account.
 */
public interface Account {

    /**
     * Getter for balance property.
     * 
     * @return balance
     */
    public int getBalance();

    /**
     * Getter for ownerName property.
     * 
     * @return ownerName
     */
    public String getOwnerName();

    /**
     * Setter for ownerName property.
     * 
     * @param ownerName
     *            ownerName
     */
    public void setOwnerName(String ownerName);

    /**
     * Getter for accountId property.
     * 
     * @return accountId
     */
    public String getAccountID();

    /**
     * Deposit a specified amount to the account. Updates the balance
     * correspondingly, and adds a corresponding Transaction to the Account.
     * 
     * @param amt
     *            the amount to deposit.
     * @see Transaction
     */
    public void deposit(int amt);

    /**
     * Withdraw a specified amount from the account. Updates the balance
     * correspondingly, and adds a corresponding Transaction to the Account.
     * 
     * @param amt
     *            the amount to withdraw.
     * @throws AccountException
     *             if not enough funding exists.
     * @see Transaction
     */
    public void withdraw(int amt) throws AccountException;

    /**
     * Get transaction record for this account.
     * 
     * @see Transaction
     * @return list of Transaction objects.
     */
    public List<Transaction> getTransctions();

    public void setSupervisor(Supervisor superVisor);
}
